pyxmpp2.streamsasl

Package pyxmpp2 :: Module streamsasl |
[hide private]

# Module streamsasl

SASL support XMPP streams.

Normative reference:
  - RFC 6120

Classes | [hide private]
| DefaultPasswordManager Default password manager.
| StreamSASLHandler SASL authentication handler XMPP streams.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.streamsasl")`
| MECHANISMS_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}mechanisms``'``
| MECHANISM_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}mechanism``'``
| CHALLENGE_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}challenge``'``
| SUCCESS_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}success``'``
| FAILURE_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}failure``'``
| AUTH_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}auth``'``
| RESPONSE_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}response``'``
| ABORT_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-sasl}abort``'``